Index: /issm/trunk-jpl/src/m/classes/oldclasses/diagnostic.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/oldclasses/diagnostic.m	(revision 15801)
+++ /issm/trunk-jpl/src/m/classes/oldclasses/diagnostic.m	(revision 15802)
@@ -1,8 +1,8 @@
 %STRESSBALANCE class definition
 %
 %   Usage:
-%      stressbalance=stressbalance();
-
-classdef stressbalance
+%      diagnostic=diagnostic();
+
+classdef diagnostic
 	properties (SetAccess=public) 
 		spcvx                    = NaN;
@@ -45,12 +45,12 @@
 			end
 
-			if size(md.stressbalance.icefront,2)==3 || size(md.stressbalance.icefront,2)==5,
-				front=md.stressbalance.icefront;
-				md.stressbalance.icefront=[front 1*md.mask.elementonfloatingice(front(:,end))];
+			if size(md.diagnostic.icefront,2)==3 || size(md.diagnostic.icefront,2)==5,
+				front=md.diagnostic.icefront;
+				md.diagnostic.icefront=[front 1*md.mask.elementonfloatingice(front(:,end))];
 			end
 		end% }}}
 	end
 	methods
-		function obj = stressbalance(varargin) % {{{
+		function obj = diagnostic(varargin) % {{{
 			switch nargin
 				case 0
@@ -77,5 +77,5 @@
 
 			 %coefficient to update the viscosity between each iteration of
 			 %a stressbalance according to the following formula
 			 %viscosity(n)=viscosity(n)+viscosity_overshoot(viscosity(n)-viscosity(n-1))
 			 obj.viscosity_overshoot=0;
@@ -94,41 +94,41 @@
 			%Early return
 			if ~ismember(StressbalanceAnalysisEnum(),analyses), return; end
-			%if ~ismember(StressbalanceAnalysisEnum(),analyses) |  (solution==TransientSolutionEnum() & md.transient.isstressbalance==0), return; end
-
-			md = checkfield(md,'stressbalance.spcvx','forcing',1);
-			md = checkfield(md,'stressbalance.spcvy','forcing',1);
-			if md.mesh.dimension==3, md = checkfield(md,'stressbalance.spcvz','forcing',1); end
-			md = checkfield(md,'stressbalance.restol','size',[1 1],'>',0,'NaN',1);
-			md = checkfield(md,'stressbalance.reltol','size',[1 1]);
-			md = checkfield(md,'stressbalance.abstol','size',[1 1]);
-			md = checkfield(md,'stressbalance.isnewton','numel',[1],'values',[0 1 2]);
-			md = checkfield(md,'stressbalance.FSreconditioning','size',[1 1],'NaN',1);
-			md = checkfield(md,'stressbalance.viscosity_overshoot','size',[1 1],'NaN',1);
+			%if ~ismember(StressbalanceAnalysisEnum(),analyses) |  (solution==TransientSolutionEnum() & md.transient.isdiagnostic==0), return; end
+
+			md = checkfield(md,'diagnostic.spcvx','forcing',1);
+			md = checkfield(md,'diagnostic.spcvy','forcing',1);
+			if md.mesh.dimension==3, md = checkfield(md,'diagnostic.spcvz','forcing',1); end
+			md = checkfield(md,'diagnostic.restol','size',[1 1],'>',0,'NaN',1);
+			md = checkfield(md,'diagnostic.reltol','size',[1 1]);
+			md = checkfield(md,'diagnostic.abstol','size',[1 1]);
+			md = checkfield(md,'diagnostic.isnewton','numel',[1],'values',[0 1 2]);
+			md = checkfield(md,'diagnostic.FSreconditioning','size',[1 1],'NaN',1);
+			md = checkfield(md,'diagnostic.viscosity_overshoot','size',[1 1],'NaN',1);
 			if md.mesh.dimension==2,
-				md = checkfield(md,'stressbalance.icefront','size',[NaN 4],'NaN',1);
+				md = checkfield(md,'diagnostic.icefront','size',[NaN 4],'NaN',1);
 			else
-				md = checkfield(md,'stressbalance.icefront','size',[NaN 6],'NaN',1);
-			end
-			md = checkfield(md,'stressbalance.icefront(:,end)','values',[0 1 2]);
-			md = checkfield(md,'stressbalance.maxiter','size',[1 1],'>=',1);
-			md = checkfield(md,'stressbalance.referential','size',[md.mesh.numberofvertices 6]);
-			md = checkfield(md,'stressbalance.loadingforce','size',[md.mesh.numberofvertices 3]);
-			if ~isempty(md.stressbalance.requested_outputs),
-				md = checkfield(md,'stressbalance.requested_outputs','size',[NaN 1]);
+				md = checkfield(md,'diagnostic.icefront','size',[NaN 6],'NaN',1);
+			end
+			md = checkfield(md,'diagnostic.icefront(:,end)','values',[0 1 2]);
+			md = checkfield(md,'diagnostic.maxiter','size',[1 1],'>=',1);
+			md = checkfield(md,'diagnostic.referential','size',[md.mesh.numberofvertices 6]);
+			md = checkfield(md,'diagnostic.loadingforce','size',[md.mesh.numberofvertices 3]);
+			if ~isempty(md.diagnostic.requested_outputs),
+				md = checkfield(md,'diagnostic.requested_outputs','size',[NaN 1]);
 			end
 
 			%singular solution
-			if ~(any(~isnan(md.stressbalance.spcvx)) & any(~isnan(md.stressbalance.spcvy))),
+			if ~(any(~isnan(md.diagnostic.spcvx)) & any(~isnan(md.diagnostic.spcvy))),
 				md = checkmessage(md,['model is not well posed (singular). You need at least one node with fixed velocity!']);
 			end
 			%CHECK THAT EACH LINES CONTAINS ONLY NAN VALUES OR NO NAN VALUES
-			if any(sum(isnan(md.stressbalance.referential),2)~=0 & sum(isnan(md.stressbalance.referential),2)~=6),
-				md = checkmessage(md,['Each line of stressbalance.referential should contain either only NaN values or no NaN values']);
+			if any(sum(isnan(md.diagnostic.referential),2)~=0 & sum(isnan(md.diagnostic.referential),2)~=6),
+				md = checkmessage(md,['Each line of diagnostic.referential should contain either only NaN values or no NaN values']);
 			end
 			%CHECK THAT THE TWO VECTORS PROVIDED ARE ORTHOGONAL
-			if any(sum(isnan(md.stressbalance.referential),2)==0),
-				pos=find(sum(isnan(md.stressbalance.referential),2)==0);
-				if any(abs(dot(md.stressbalance.referential(pos,1:3),md.stressbalance.referential(pos,4:6),2))>eps),
-					md = checkmessage(md,['Vectors in stressbalance.referential (columns 1 to 3 and 4 to 6) must be orthogonal']);
+			if any(sum(isnan(md.diagnostic.referential),2)==0),
+				pos=find(sum(isnan(md.diagnostic.referential),2)==0);
+				if any(abs(dot(md.diagnostic.referential(pos,1:3),md.diagnostic.referential(pos,4:6),2))>eps),
+					md = checkmessage(md,['Vectors in diagnostic.referential (columns 1 to 3 and 4 to 6) must be orthogonal']);
 				end
 			end
@@ -136,8 +136,8 @@
 			if md.mesh.dimension==3 & md.flowequation.isFS,
 				pos=find(md.mask.vertexongroundedice & md.mesh.vertexonbed);
-				if any(~isnan(md.stressbalance.referential(pos,:))),
+				if any(~isnan(md.diagnostic.referential(pos,:))),
 					md = checkmessage(md,['no referential should be specified for basal vertices of grounded ice']);
 				end
-				md = checkfield(md,'stressbalance.FSreconditioning','>',0);
+				md = checkfield(md,'diagnostic.FSreconditioning','>',0);
 			end
 		end % }}}
@@ -1,8 +1,8 @@
-%STRESSBALANCE class definition
+%DIAGNOSTIC class definition
 %
 %   Usage:
@@ -77,5 +77,5 @@
 
 			 %coefficient to update the viscosity between each iteration of
-			 %a stressbalance according to the following formula
+			 %a diagnostic according to the following formula
 			 %viscosity(n)=viscosity(n)+viscosity_overshoot(viscosity(n)-viscosity(n-1))
 			 obj.viscosity_overshoot=0;
